import sys

from twisted.internet import reactor
from twisted.internet.endpoints import TCP4ServerEndpoint, TCP6ServerEndpoint
from twisted.internet.error import CannotListenError

from syncplay.server import SyncFactory, ConfigurationGetter


class ServerStatus:
    listening6 = False
    listening4 = False


def isListening6(f):
    ServerStatus.listening6 = True


def isListening4(f):
    ServerStatus.listening4 = True


def failed6(f):
    ServerStatus.listening6 = False
    print(f.value)
    print("IPv6 listening failed.")


def failed4(f):
    ServerStatus.listening4 = False
    if f.type is CannotListenError and ServerStatus.listening6:
        pass
    else:
        print(f.value)
        print("IPv4 listening failed.")


def main():
    argsGetter = ConfigurationGetter()
    args = argsGetter.getConfiguration()

    factory = SyncFactory(
        args.port,
        args.password,
        args.motd_file,
        args.rooms_db_file,
        args.permanent_rooms_file,
        args.isolate_rooms,
        args.salt,
        args.disable_ready,
        args.disable_chat,
        args.max_chat_message_length,
        args.max_username_length,
        args.stats_db_file,
        args.tls
    )

    if args.ipv6_only is True:
        endpoint6 = TCP6ServerEndpoint(reactor, int(args.port), interface=args.interface_ipv6)
        endpoint6.listen(factory).addCallbacks(isListening6, failed6)
    elif args.ipv4_only is True:
        endpoint4 = TCP4ServerEndpoint(reactor, int(args.port), interface=args.interface_ipv4)
        endpoint4.listen(factory).addCallbacks(isListening4, failed4)
    else:
        endpoint6 = TCP6ServerEndpoint(reactor, int(args.port), interface=args.interface_ipv6)
        endpoint6.listen(factory).addCallbacks(isListening6, failed6)
        endpoint4 = TCP4ServerEndpoint(reactor, int(args.port), interface=args.interface_ipv4)
        endpoint4.listen(factory).addCallbacks(isListening4, failed4)

    if ServerStatus.listening6 or ServerStatus.listening4:
        reactor.run()
    else:
        print("Unable to listen using either IPv4 and IPv6 protocols. Quitting the server now.")
        sys.exit()


if __name__ == "__main__":
    main()




import os.path

from syncplay import constants
from syncplay.messages import getMessage
from syncplay.players.mpc import MPCHCAPIPlayer


class MpcBePlayer(MPCHCAPIPlayer):
    @staticmethod
    def run(client, playerPath, filePath, args):
        args.extend(['/open', '/new'])
        mpc = MpcBePlayer(client)
        mpc._mpcApi.callbacks.onConnected = lambda: mpc.initPlayer(filePath if filePath else None)
        mpc._mpcApi.startMpc(MpcBePlayer.getExpandedPath(playerPath), args)
        client.initPlayer(mpc)
        return mpc

    @staticmethod
    def getDefaultPlayerPathsList():
        return constants.MPC_BE_PATHS

    @staticmethod
    def getIconPath(path):
        return constants.MPC_BE_ICONPATH

    @staticmethod
    def isValidPlayerPath(path):
        if MpcBePlayer.getExpandedPath(path):
            return True
        return False

    @staticmethod
    def getExpandedPath(path):
        if os.path.isfile(path):
            if (
                path.lower().endswith('mpc-be.exe'.lower()) or
                path.lower().endswith('mpc-be64.exe'.lower()) or
                path.lower().endswith('mpc-beportable.exe'.lower())
            ):
                return path
        if os.path.isfile(path + "mpc-be.exe"):
            path += "mpc-be.exe"
            return path
        if os.path.isfile(path + "\\mpc-be.exe"):
            path += "\\mpc-be.exe"
            return path
        if os.path.isfile(path + "mpc-beportable.exe"):
            path += "mpc-beportable.exe"
            return path
        if os.path.isfile(path + "\\mpc-beportable.exe"):
            path += "\\mpc-beportable.exe"
            return path
        if os.path.isfile(path + "mpc-be64.exe"):
            path += "mpc-be64.exe"
            return path
        if os.path.isfile(path + "\\mpc-be64.exe"):
            path += "\\mpc-be64.exe"
            return path

    @staticmethod
    def getMinVersionErrorMessage():
        return getMessage("mpc-be-version-insufficient-error").format(constants.MPC_BE_MIN_VER)



# coding:utf8

"""Brazilian Portuguese dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

pt_BR = {
    "LANGUAGE": "Português do Brasil",
    "LANGUAGE-TAG": "pt_BR",

    # Strings for Windows NSIS installer
    "installer-language-file": "PortugueseBR.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "Associar Syncplay aos arquivos multimídia.",
    "installer-shortcut": "Criar atalhos nos seguintes locais:",
    "installer-start-menu": "Menu Iniciar",
    "installer-desktop": "Área de trabalho",
    "installer-quick-launch-bar": "Barra de acesso rápido",
    "installer-automatic-updates": "Verificar atualizações automaticamente",
    "installer-uninstall-configuration": "Deletar arquivo de configuração.",

    # Client notifications
    "config-cleared-notification": "Configurações removidas. Mudanças serão salvas quando você armazenar uma configuração válida.",

    "relative-config-notification": "Arquivo(s) de configuração relativa carregado(s): {}",

    "connection-attempt-notification": "Tentando se conectar a {}:{}",  # Port, IP
    "reconnection-attempt-notification": "Conexão com o servidor perdida, tentando reconectar",
    "disconnection-notification": "Desconectado do servidor",
    "connection-failed-notification": "Conexão com o servidor falhou",
    "connected-successful-notification": "Conectado com sucesso ao servidor",
    "retrying-notification": "%s, tentando novamente em %d segundos...",  # Seconds
    "reachout-successful-notification": "Alcançado {} ({}) com sucesso",

    "rewind-notification": "Retrocedendo devido à diferença de tempo com {}",  # User
    "fastforward-notification": "Avançando devido à diferença de tempo com {}",  # User
    "slowdown-notification": "Diminuindo a velocidade devido à diferença de tempo com {}",  # User
    "revert-notification": "Revertendo velocidade ao normal",

    "pause-notification": "{} pausou ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
    "unpause-notification": "{} despausou",  # User
    "seek-notification": "{} saltou de {} para {}",  # User, from time, to time

    "current-offset-notification": "Deslocamento atual: {} segundos",  # Offset

    "media-directory-list-updated-notification": "Os diretórios de mídia do Syncplay foram atualizados.",

    "room-join-notification": "{} entrou na sala: '{}'",  # User
    "left-notification": "{} saiu da sala",  # User
    "left-paused-notification": "{} saiu da sala, {} pausou",  # User who left, User who paused
    "playing-notification": "{} está tocando '{}' ({})",  # User, file, duration
    "playing-notification/room-addendum":  " na sala: '{}'",  # Room

    "not-all-ready": "Não está pronto: {}",  # Usernames
    "all-users-ready": "Todo mundo está pronto ({} users)",  # Number of ready users
    "ready-to-unpause-notification": "Agora você está definido como pronto - despause novamente para despausar",
    "set-as-ready-notification": "Agora você está definido como pronto",
    "set-as-not-ready-notification": "Agora você está definido como não pronto",
    "autoplaying-notification": "Reprodução automática em {}...",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "Identificando-se como operador da sala com a senha '{}'...",
    "failed-to-identify-as-controller-notification": "{} falhou ao se identificar como operador da sala.",
    "authenticated-as-controller-notification": "{} autenticou-se como um operador da sala",
    "created-controlled-room-notification": "Criou a sala gerenciada '{}' com a senha '{}'. Por favor, salve essa informação para futura referência!\n\nEm uma sala gerenciada, todos são mantidos em sincronia com o(s) operador(es) de sala, que é/são o(s) único(s) que pode(m) pausar, despausar, pular, e mudar a playlist.\n\nVocê deve pedir usuários comuns para se entrarem à sala '{}', mas os operadores de sala podem se entrar à sala '{}' para autenticarem-se automaticamente.", # RoomName, operatorPassword, roomName, roomName:operatorPassword

    "other-set-as-ready-notification": "{} was set as ready by {}", # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "O arquivo que você está tocando parece ser diferente do arquivo de {}",  # User
    "file-differences-notification": "Seus arquivos se diferem da(s) seguinte(s) forma(s): {}",  # Differences
    "room-file-differences": "Diferenças de arquivos: {}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "nome",
    "file-difference-filesize": "tamanho",
    "file-difference-duration": "duração",
    "alone-in-the-room": "Você está sozinho na sala",

    "different-filesize-notification": " (o tamanho do arquivo dele(s) é diferente do seu!)",
    "userlist-playing-notification": "{} está tocando:",  # Username
    "file-played-by-notification": "Arquivo: {} está sendo tocado por:",  # File
    "no-file-played-notification": "{} não está tocando um arquivo",  # Username
    "notplaying-notification": "Pessoas que não estão tocando nenhum arquivo:",
    "userlist-room-notification":  "Na sala '{}':",  # Room
    "userlist-file-notification": "Arquivo",
    "controller-userlist-userflag": "Operador",
    "ready-userlist-userflag": "Pronto",

    "update-check-failed-notification": "Não foi possível verificar automaticamente se o Syncplay {} é a versão mais recente. Deseja visitar https://syncplay.pl/ para checar manualmente por atualizações?",  # Syncplay version
    "syncplay-uptodate-notification": "O Syncplay está atualizado",
    "syncplay-updateavailable-notification": "Uma nova versão do Syncplay está disponível. Deseja visitar a página de lançamentos?",

    "mplayer-file-required-notification": "Syncplay com mplayer requer que você forneça o arquivo ao começar",
    "mplayer-file-required-notification/example": "Exemplo de uso: syncplay [opções] [url|caminho_ate_o_arquivo/]nome_do_arquivo",
    "mplayer2-required": "O Syncplay é incompatível com o MPlayer 1.x, por favor use mplayer2 ou mpv",

    "unrecognized-command-notification": "Comando não reconhecido",
    "commandlist-notification": "Comandos disponíveis:",
    "commandlist-notification/room": "\tr [nome] - muda de sala",
    "commandlist-notification/list": "\tl - mostra lista de usuários",
    "commandlist-notification/undo": "\tu - desfaz último salto",
    "commandlist-notification/pause": "\tp - alterna pausa",
    "commandlist-notification/seek": "\t[s][+-]tempo - salta para o valor de tempo fornecido, se + ou - não forem especificados, será o tempo absoluto em segundos ou minutos:segundos",
    "commandlist-notification/offset": "\to[+-]duração - Desloca a reprodução local pelo valor de duração fornecido (em segundos ou min:seg) em relação à posição de tepmo do servidor - essa é uma função descontinuada",
    "commandlist-notification/help": "\th - esta mensagem de ajuda",
    "commandlist-notification/toggle": "\tt - alterna o seu status de prontidão para assistir",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
    "commandlist-notification/create": "\tc [nome] - cria uma sala gerenciada usando o nome da sala atual",
    "commandlist-notification/auth": "\ta [senha] - autentica-se como operador da sala com a senha",
    "commandlist-notification/chat": "\tch [mensagem] - envia uma mensagem no chat da sala",
    "commandList-notification/queue": "\tqa [arquivo/url] - adiciona um arquivo ou URL para o final da playlist",
    "commandList-notification/queueandselect": "\tqas [arquivo/url] - adiciona um arquivo ou URL para o final da playlist e o seleciona",
    "commandList-notification/playlist": "\tql - mostra a playlist atual",
    "commandList-notification/select": "\tqs [índice] - seleciona um item da playlist",
    "commandList-notification/next": "\tqn - select next entry in the playlist", # TODO: Translate
    "commandList-notification/delete": "\tqd [index] - remove um item da playlist",
    "syncplay-version-notification": "Versão do Syncplay: {}",  # syncplay.version
    "more-info-notification": "Mais informações disponíveis em: {}",  # projectURL

    "gui-data-cleared-notification": "O Syncplay limpou o caminho e o estado de dados da janela usados pela GUI.",
    "language-changed-msgbox-label": "O idioma será alterado quando você salvar as mudanças e abrir o Syncplay novamente.",
    "promptforupdate-label": "Permite o Syncplay verificar automaticamente por atualizações de tempos em tempos?",

    "media-player-latency-warning": "Aviso: O reprodutor de mídia demorou {} para responder. Se você tiver problemas de sincronização, feche outros programas para liberar recursos do sistema e, se isso não funcionar, tente outro reprodutor de mídia.",  # Seconds to respond
    "mpv-unresponsive-error": "O mpv não respondeu por {} segundos, portanto parece que não está funcionando. Por favor, reinicie o Syncplay.",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Aperte Enter para sair\n",

    # Client errors
    "missing-arguments-error": "Alguns argumentos necessários estão faltando, por favor reveja --help",
    "server-timeout-error": "A conexão com o servidor ultrapassou o tempo limite",
    "mpc-slave-error": "Não foi possível abrir o MPC no slave mode!",
    "mpc-version-insufficient-error": "A versão do MPC é muito antiga, por favor use `mpc-hc` >= `{}`",
    "mpc-be-version-insufficient-error": "A versão do MPC-BE é muito antiga, por favor use `mpc-be` >= `{}`",
    "mpv-version-error": "O Syncplay não é compatível com esta versão do mpv. Por favor, use uma versão diferente do mpv (por exemplo, Git HEAD).",
    "mpv-failed-advice": "O motivo pelo qual o mpv não pode ser iniciado pode ser devido ao uso de argumentos da linha de comando não suportados ou a uma versão não suportada do mpv.",
    "player-file-open-error": "O reprodutor falhou ao abrir o arquivo",
    "player-path-error": "O caminho até o arquivo executável do reprodutor não está configurado corretamente. Os reprodutores suportados são: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 e IINA",
    "hostname-empty-error": "O endereço do servidor não pode estar vazio",
    "empty-error": "{} não pode estar vazio",  # Configuration
    "media-player-error": "Erro do reprodutor de mídia: \"{}\"",  # Error line
    "unable-import-gui-error": "Não foi possível importar bibliotecas da GUI. Se você não possuir o PySide instalado, instale-o para que a GUI funcione. If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
    "unable-import-twisted-error": "Não foi possível importar o Twisted. Por favor, instale o Twisted v16.4.0 ou superior.",

    "arguments-missing-error": "Alguns argumentos necessários estão faltando, por favor reveja --help",

    "unable-to-start-client-error": "Não foi possível iniciar o cliente",

    "player-path-config-error": "O caminho até o arquivo executável do reprodutor não está configurado corretamente. Os reprodutores suportados são: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 e IINA.",
    "no-file-path-config-error": "O arquivo deve ser selecionado antes de iniciar seu reprodutor",
    "no-hostname-config-error": "O endereço do servidor não pode estar vazio",
    "invalid-port-config-error": "A porta deve ser válida",
    "empty-value-config-error": "{} não pode estar vazio",  # Config option

    "not-json-error": "Não é uma string codificada como JSON\n",
    "hello-arguments-error": "Not enough Hello arguments\n",  # DO NOT TRANSLATE
    "version-mismatch-error": "Discrepância entre versões do client e do servidor\n",
    "vlc-failed-connection": "Falha ao conectar ao VLC. Se você não instalou o syncplay.lua e está usando a versão mais recente do VLC, por favor veja https://syncplay.pl/LUA/ para mais instruções. Syncplay e VLC 4 são atualmente incompatíveis, portanto use VLC 3 ou use outro reprodutor, como o mpv.",
    "vlc-failed-noscript": "O VLC reportou que a interface de script do syncplay.lua não foi instalada. Por favor, veja https://syncplay.pl/LUA/ para mais instruções.",
    "vlc-failed-versioncheck": "Esta versão do VLC não é suportada pelo Syncplay.",
    "vlc-initial-warning": 'O VLC nem sempre fornece informações precisas de posição para o Syncplay, especialmente para arquivos .mp4 ou .avi. Se você experienciar problemas com busca (seeking) incorreta, por favor, tente um reprodutor de mídia alternativo, como o <a href="https://mpv.io/">mpv</a> (ou <a href="https://github.com/stax76/mpv.net/">mpv.net</a>, uma alternativa mais simples do mpv a usuários de Windows).',

    "feature-sharedPlaylists": "playlists compartilhadas",  # used for not-supported-by-server-error
    "feature-chat": "chat",  # used for not-supported-by-server-error
    "feature-readiness": "prontidão",  # used for not-supported-by-server-error
    "feature-managedRooms": "salas gerenciadas",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "O recurso {} não é suportado por este servidor.",  # feature
    "shared-playlists-not-supported-by-server-error": "O recurso de playlists compartilhadas pode não ser suportado por este servidor. Para garantir que funcione corretamente, é necessário um servidor rodando Syncplay {} ou superior, mas este está rodando Syncplay {}.",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "O recurso de playlists compartilhadas foi desativado nas configurações do servidor. Para usar este recurso, você precisa se conectar a um servidor diferente.",

    "invalid-seek-value": "Valor de salto inválido",
    "invalid-offset-value": "Valor de deslocamento inválido",

    "switch-file-not-found-error": "Não foi possível mudar para o arquivo '{0}'. O Syncplay procura nos diretórios de mídia especificados.",  # File not found
    "folder-search-timeout-error": "A busca por mídias no diretório de mídias foi cancelada pois demorou muito tempo para procurar em '{}' (after having processed the first {} files). Isso ocorre quando você seleciona uma pasta com muitas subpastas em sua lista de pastas de mídias a serem pesquisadas.  Para que a troca automática de arquivos funcione novamente, selecione 'Arquivo -> Definir diretórios de mídias' na barra de menus e remova esse diretório ou substitua-o por uma subpasta apropriada. Se a pasta não tiver problemas, é possível reativá-la selecionando 'Arquivo -> Definir diretórios de mídias' e pressionando 'OK'.",  # Folder, Files processed - TODO: Update translation (refer back to original English text)
    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "A busca por mídias em '{}' foi interrompida, pois demorou muito para acessar o diretório. Isso pode acontecer se for uma unidade de rede ou se você configurar sua unidade para hibernar depois de um período de inatividade. Para que a troca automática de arquivos funcione novamente, vá para 'Arquivo -> Definir diretórios de mídias' e remova o diretório ou resolva o problema (por exemplo, alterando as configurações de economia de energia da unidade).",  # Folder
    "added-file-not-in-media-directory-error": "Você carregou um arquivo em '{}', que não é um diretório de mídias conhecido. Você pode adicioná-lo isso como um diretório de mídia selecionando 'Arquivo -> Definir diretórios de mídias' na barra de menus.",  # Folder
    "no-media-directories-error": "Nenhum diretório de mídias foi definido. Para que os recursos de playlists compartilhadas e troca automática de arquivos funcionem corretamente, selecione 'Arquivo -> Definir diretórios de mídias' e especifique onde o Syncplay deve procurar para encontrar arquivos de mídia.",
    "cannot-find-directory-error": "Não foi possível encontrar o diretório de mídia '{}'. Para atualizar sua lista de diretórios de mídias, selecione 'Arquivo -> Definir diretórios de mídias' na barra de menus e especifique onde o Syncplay deve procurar para encontrar arquivos de mídia.",

    "failed-to-load-server-list-error": "Não foi possível carregar a lista de servidores públicos. Por favor, visite https://www.syncplay.pl/ em seu navegador.",

    # Client arguments
    "argument-description": 'Solução para sincronizar reprodução de múltiplas instâncias de reprodutores de mídia pela rede.',
    "argument-epilog": 'Se nenhuma opção for fornecida, os valores de _config serão usados',
    "nogui-argument": 'não mostrar GUI',
    "host-argument": 'endereço do servidor',
    "name-argument": 'nome de usuário desejado',
    "debug-argument": 'modo depuração',
    "force-gui-prompt-argument": 'fazer o prompt de configuração aparecer',
    "no-store-argument": 'não guardar valores em .syncplay',
    "room-argument": 'sala padrão',
    "password-argument": 'senha do servidor',
    "player-path-argument": 'caminho até o executável do reprodutor de mídia',
    "file-argument": 'arquivo a ser tocado',
    "args-argument": 'opções do reprodutor; se você precisar passar opções começando com -, as preceda com um único argumento \'--\'',
    "clear-gui-data-argument": 'redefine o caminho e o estado de dados da janela da GUI para as de QSettings',
    "language-argument": 'idioma para mensagens do Syncplay ({})', # Languages

    "version-argument": 'exibe sua versão',
    "version-message": "Você está usando o Syncplay versão {} ({})",

    "load-playlist-from-file-argument": "carrega playlist de um arquivo de texto (uma entrada por linha)",

    # Client labels
    "config-window-title": "Configuração do Syncplay",

    "connection-group-title": "Configurações de conexão",
    "host-label": "Endereço do servidor: ",
    "name-label": "Nome de usuário (opcional): ",
    "password-label": "Senha do servidor (se existir): ",
    "room-label": "Sala padrão: ",
    "roomlist-msgbox-label": "Edite a lista de salas (uma por linha)",

    "media-setting-title": "Configurações do reprodutor de mídia",
    "executable-path-label": "Executável do reprodutor:",
    "media-path-label": "Arquivo de vídeo ou URL (opcional):",
    "player-arguments-label": "Argumentos para o reprodutor (opcional):",
    "browse-label": "Navegar",
    "update-server-list-label": "Atualizar lista",

    "more-title": "Mostrar mais configurações",
    "never-rewind-value": "Nunca",
    "seconds-suffix": " s",
    "privacy-sendraw-option": "Enviar bruto",
    "privacy-sendhashed-option": "Enviar hasheado",
    "privacy-dontsend-option": "Não enviar",
    "filename-privacy-label": "Informação do nome do arquivo:",
    "filesize-privacy-label": "Informação do tamanho do arquivo:",
    "checkforupdatesautomatically-label": "Verificar atualizações do Syncplay automaticamente",
    "autosavejoinstolist-label": "Adicionar salas que você visitou para a sua lista de salas",
    "slowondesync-label": "Diminuir velocidade em dessincronizações menores (não suportado pelo MPC-HC/BE)",
    "rewindondesync-label": "Retroceder em dessincronização maiores (recomendado)",
    "fastforwardondesync-label": "Avançar se estiver ficando para trás (recomendado)",
    "dontslowdownwithme-label": "Nunca desacelerar ou retroceder outros (experimental)",
    "pausing-title": "Pausando",
    "pauseonleave-label": "Pausar quando um usuário sair (por exemplo, se for desconectado)",
    "readiness-title": "Estado de prontidão inicial",
    "readyatstart-label": "Marque-me como 'pronto para assistir' por padrão",
    "forceguiprompt-label": "Não mostrar a janela de configuração do Syncplay",  # (Inverted)
    "showosd-label": "Ativar mensagens na tela (OSD)",

    "showosdwarnings-label": "Incluir avisos (por exemplo, quando arquivos são diferentes, usuários não estão prontos, etc)",
    "showsameroomosd-label": "Incluir eventos da sua sala",
    "shownoncontrollerosd-label": "Incluir eventos de não operadores em salas gerenciadas",
    "showdifferentroomosd-label": "Incluir eventos de outras salas",
    "showslowdownosd-label": "Incluir notificações de desaceleramento ou retrocedimento",
    "language-label": "Idioma:",
    "automatic-language": "Padrão ({})",  # Default language
    "showdurationnotification-label": "Avisar sobre discrepância nas durações dos arquivos de mídia",
    "basics-label": "Básicos",
    "readiness-label": "Tocar/Pausar",
    "misc-label": "Miscelânea",
    "core-behaviour-title": "Comportamento principal da sala",
    "syncplay-internals-title": "Configurações internas do Syncplay",
    "syncplay-mediasearchdirectories-title": "Diretórios a buscar por mídias",
    "syncplay-mediasearchdirectories-label": "Diretórios a buscar por mídias (um caminho por linha)",
    "sync-label": "Sincronização",
    "sync-otherslagging-title": "Se outros estiverem ficando pra trás...",
    "sync-youlaggging-title": "Se você estiver ficando pra trás...",
    "messages-label": "Mensagens",
    "messages-osd-title": "Configurações das mensagens na tela (OSD)",
    "messages-other-title": "Outras configurações de tela",
    "chat-label": "Chat",
    "privacy-label": "Privacidade",  # Currently unused, but will be brought back if more space is needed in Misc tab
    "privacy-title": "Configurações de privacidade",
    "unpause-title": "Se você apertar play, definir-se como pronto e:",
    "unpause-ifalreadyready-option": "Despausar se você já estiver definido como pronto",
    "unpause-ifothersready-option": "Despausar se você já estiver pronto ou outros na sala estiverem prontos (padrão)",
    "unpause-ifminusersready-option": "Despausar se você já estiver pronto ou outros na sala estiverem prontos e o número mínimo de usuários está pronto",
    "unpause-always": "Sempre despausar",
    "syncplay-trusteddomains-title": "Domínios confiáveis (para serviços de streaming e conteúdo hospedado)",

    "chat-title": "Digitação de mensagem no chat",
    "chatinputenabled-label": "Habilitar digitação no chat via mpv",
    "chatdirectinput-label": "Permitir digitação instantânea no chat (evita ter de apertar Enter para abrir o chat)",
    "chatinputfont-label": "Fonte da digitação no chat",
    "chatfont-label": "Definir fonte",
    "chatcolour-label": "Definir cor",
    "chatinputposition-label": "Posição da área de digitação de mensagens no mpv",
    "chat-top-option": "Topo",
    "chat-middle-option": "Meio",
    "chat-bottom-option": "Baixo",
    "chatoutputheader-label": "Saída de mensagem do chat",
    "chatoutputfont-label": "Fonte da saída de chat",
    "chatoutputenabled-label": "Habilitar saída de chat no reprodutor de mídia (apenas no mpv por enquanto)",
    "chatoutputposition-label": "Modo de saída",
    "chat-chatroom-option": "Estilo da sala de bate-papo",
    "chat-scrolling-option": "Estilo de rolagem",

    "mpv-key-tab-hint": "[TAB] para alternar acesso instantâneo ao chat.",
    "mpv-key-hint": "[ENTER] para enviar mensagem. [ESC] para sair do modo de chat.",
    "alphakey-mode-warning-first-line": "Você pode usar os antigos atalhos do mpv com as teclas a-z.",
    "alphakey-mode-warning-second-line": "Aperte [TAB] para retornar ao modo de chat instantâneo do Syncplay.",

    "help-label": "Ajuda",
    "reset-label": "Restaurar padrões",
    "run-label": "Começar Syncplay",
    "storeandrun-label": "Salvar mudanças e começar Syncplay",

    "contact-label": "Sinta-se livre para mandar um e-mail para <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a>, <a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>abrir uma issue</nobr></a> para reportar um bug/problema via GitHub, <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>começar uma discussão</nobr></a> para fazer uma sugestão ou uma pergunta via GitHub, <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>curtir nossa página no Facebook</nobr></a>, <a href=\"https://twitter.com/Syncplay/\"><nobr>nos seguir no Twitter</nobr></a>, ou visitar <a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a>. Não use o Syncplay para mandar informações sensíveis/confidenciais.",
    
    "joinroom-label": "Juntar-se a uma sala",
    "joinroom-menu-label": "Juntar-se à sala {}",
    "seektime-menu-label": "Saltar para o tempo",
    "undoseek-menu-label": "Desfazer salto",
    "play-menu-label": "Tocar",
    "pause-menu-label": "Pausar",
    "playbackbuttons-menu-label": "Mostrar botões de reprodução",
    "autoplay-menu-label": "Mostrar botão de reprodução automática",
    "autoplay-guipushbuttonlabel": "Tocar quando todos estiverem prontos",
    "autoplay-minimum-label": "Mín. de usuários:",
    "hideemptyrooms-menu-label": "Esconder salas persistentes vazias",

    "sendmessage-label": "Enviar",

    "ready-guipushbuttonlabel": "Estou pronto para assistir!",

    "roomuser-heading-label": "Sala / Usuário",
    "size-heading-label": "Tamanho",
    "duration-heading-label": "Duração",
    "filename-heading-label": "Nome do arquivo",
    "notifications-heading-label": "Notificações",
    "userlist-heading-label": "Lista de quem está tocando o quê",

    "browseformedia-label": "Navegar por arquivos de mídia",

    "file-menu-label": "&Arquivo",  # & precedes shortcut key
    "openmedia-menu-label": "A&brir arquivo de mídia",
    "openstreamurl-menu-label": "Abrir &URL de stream de mídia",
    "setmediadirectories-menu-label": "Definir &diretórios de mídias",
    "loadplaylistfromfile-menu-label": "&Carregar playlist de arquivo",
    "saveplaylisttofile-menu-label": "&Salvar playlist em arquivo",
    "exit-menu-label": "&Sair",
    "advanced-menu-label": "A&vançado",
    "window-menu-label": "&Janela",
    "setoffset-menu-label": "Definir &deslocamento",
    "createcontrolledroom-menu-label": "&Criar sala gerenciada",
    "identifyascontroller-menu-label": "&Identificar-se como operador da sala",
    "settrusteddomains-menu-label": "D&efinir domínios confiáveis",
    "addtrusteddomain-menu-label": "Adicionar {} como domínio confiável",  # Domain

    "edit-menu-label": "&Editar",
    "cut-menu-label": "Cor&tar",
    "copy-menu-label": "&Copiar",
    "paste-menu-label": "C&olar",
    "selectall-menu-label": "&Selecionar todos",

    "playback-menu-label": "&Reprodução",

    "help-menu-label": "&Ajuda",
    "userguide-menu-label": "Abrir &guia de usuário",
    "update-menu-label": "&Verificar atualizações",

    "startTLS-initiated": "Tentando estabelecer conexão segura",
    "startTLS-secure-connection-ok": "Conexão segura estabelecida ({})",
    "startTLS-server-certificate-invalid": 'Não foi possível estabelecer uma conexão segura. O servidor usa um certificado de segurança inválido. Essa comunicação pode ser interceptada por terceiros. Para mais detalhes de solução de problemas, consulte <a href="https://syncplay.pl/trouble">aqui</a>.',
    "startTLS-server-certificate-invalid-DNS-ID": "O Syncplay não confia neste servidor pois ele usa um certificado que não é válido para seu hostname.",
    "startTLS-not-supported-client": "Este client não possui suporte para TLS",
    "startTLS-not-supported-server": "Este servidor não possui suporte para TLS",

    # TLS certificate dialog
    "tls-information-title": "Detalhes do certificado",
    "tls-dialog-status-label": "<strong>Syncplay está usando uma conexão criptografada para {}.</strong>",
    "tls-dialog-desc-label": "A criptografia com um certificado digital mantém as informações em sigilo quando são enviadas para ou do<br/>servidor {}.",
    "tls-dialog-connection-label": "Informações criptografadas usando o Transport Layer Security (TLS), versão {} com o conjunto de cifras (cipher suite)<br/>: {}.",
    "tls-dialog-certificate-label": "Certificado emitido em {} e válido até {}.",

    # About dialog
    "about-menu-label": "&Sobre o Syncplay",
    "about-dialog-title": "Sobre o Syncplay",
    "about-dialog-release": "Versão {}, lançamento {}",
    "about-dialog-license-text": "Licenciado sob a Licença&nbsp;Apache,&nbsp;Versão 2.0",
    "about-dialog-license-button": "Licença",
    "about-dialog-dependencies": "Dependências",

    "setoffset-msgbox-label": "Definir deslocamento",
    "offsetinfo-msgbox-label": "Deslocamento (veja https://syncplay.pl/guide/ para instruções de uso):",

    "promptforstreamurl-msgbox-label": "Abrir transmissão de mídia via URL",
    "promptforstreamurlinfo-msgbox-label": "URL da transmissão",

    "addfolder-label": "Adicionar pasta",

    "adduris-msgbox-label": "Adicionar URLs à playlist (uma por linha)",
    "editplaylist-msgbox-label": "Definir playlist (uma por linha)",
    "trusteddomains-msgbox-label": "Domínios para os quais é permitido trocar automaticamente (um por linha)",

    "createcontrolledroom-msgbox-label": "Criar sala gerenciada",
    "controlledroominfo-msgbox-label": "Informe o nome da sala gerenciada\r\n(veja https://syncplay.pl/guide/ para instruções de uso):",

    "identifyascontroller-msgbox-label": "Identificar-se como operador da sala",
    "identifyinfo-msgbox-label": "Informe a senha de operador para esta sala\r\n(veja https://syncplay.pl/guide/ para instruções de uso):",

    "public-server-msgbox-label": "Selecione o servidor público para esta sessão de visualização",

    "megabyte-suffix": " MB",

    # Tooltips

    "host-tooltip": "Hostname ou IP para se conectar, opcionalmente incluindo uma porta (por exemplo, syncplay.pl:8999). Só sincroniza-se com pessoas no mesmo servidor/porta.",
    "name-tooltip": "Nome pelo qual você será conhecido. Não há cadastro, então você pode facilmente mudar mais tarde. Se não for especificado, será gerado aleatoriamente.",
    "password-tooltip": "Senhas são necessárias apenas para servidores privados.",
    "room-tooltip": "O nome da sala para se conectar pode ser praticamente qualquer coisa, mas você só irá se sincronizar com pessoas na mesma sala.",

    "edit-rooms-tooltip": "Edite a lista de salas.",

    "executable-path-tooltip": "Localização do seu reprodutor de mídia preferido (mpv, mpv.net, VLC, MPC-HC/BE, mplayer2 ou IINA).",
    "media-path-tooltip": "Localização do vídeo ou transmissão a ser aberto. Necessário com o mplayer2.",
    "player-arguments-tooltip": "Argumentos de comando de linha adicionais para serem repassados ao reprodutor de mídia.",
    "mediasearcdirectories-arguments-tooltip": "Diretório onde o Syncplay vai procurar por arquivos de mídia, por exemplo quando você estiver usando o recurso de clicar para mudar. O Syncplay irá procurar recursivamente pelas subpastas.",

    "more-tooltip": "Exibe configurações menos frequentemente utilizadas.",
    "filename-privacy-tooltip": "Modo de privacidade para mandar nome de arquivo do arquivo atual para o servidor.",
    "filesize-privacy-tooltip": "Modo de privacidade para mandar tamanho do arquivo atual para o servidor.",
    "privacy-sendraw-tooltip": "Enviar esta informação sem ofuscação. Esta é a opção padrão com mais funcionalidades.",
    "privacy-sendhashed-tooltip": "Mandar versão hasheada da informação, tornando-a menos visível aos outros clients.",
    "privacy-dontsend-tooltip": "Não enviar esta informação ao servidor. Esta opção oferece a maior privacidade.",
    "checkforupdatesautomatically-tooltip": "Checar o site do Syncplay regularmente para ver se alguma nova versão do Syncplay está disponível.",
    "autosavejoinstolist-tooltip": "Quando você se juntar a uma sala em um servidor, automaticamente lembrar do nome da sala na lista de salas para entrar.",
    "slowondesync-tooltip": "Reduzir a velocidade de reprodução temporariamente quando necessário para trazer você de volta à sincronia com os outros espectadores. Não suportado pelo MPC-HC/BE.",
    "dontslowdownwithme-tooltip": "Significa que outros não serão desacelerados ou retrocedidos se sua reprodução estiver ficando para trás. Útil para operadores de salas.",
    "pauseonleave-tooltip": "Pausar reprodução se você for desconectado ou se alguém sair da sua sala.",
    "readyatstart-tooltip": "Definir-se como 'pronto' ao começar (do contrário você será definido como 'não pronto' até mudar seu estado de prontidão)",
    "forceguiprompt-tooltip": "Diálogo de configuração não será exibido ao abrir um arquivo com o Syncplay.",  # (Inverted)
    "nostore-tooltip": "Começar Syncplay com a dada configuração, mas não guardar as mudanças permanentemente.",  # (Inverted)
    "rewindondesync-tooltip": "Retroceder automaticamente quando necessário para sincronizar. Desabilitar isto pode resultar em grandes dessincronizações!",
    "fastforwardondesync-tooltip": "Avançar automaticamente quando estiver fora de sincronia com o operador da sala (ou sua posição pretendida caso 'Nunca desacelerar ou retroceder outros' estiver habilitada).",
    "showosd-tooltip": "Envia mensagens do Syncplay à tela do reprodutor de mídia (OSD).",
    "showosdwarnings-tooltip": "Mostra avisos se: estiver tocando arquivos diferentes, sozinho na sala, usuários não prontos, etc.",
    "showsameroomosd-tooltip": "Mostra notificações na tela (OSD) sobre eventos relacionados à sala em que o usuário está.",
    "shownoncontrollerosd-tooltip": "Mostra notificações na tela (OSD) sobre eventos relacionados a não operadores que estão em salas gerenciadas.",
    "showdifferentroomosd-tooltip": "Mostra notificações na tela (OSD) sobre eventos relacionados à sala em que o usuário não está.",
    "showslowdownosd-tooltip": "Mostra notificações na tela (OSD) sobre desaceleramento/retrocedimento por conta de diferença nos tempos.",
    "showdurationnotification-tooltip": "Útil quando um segmento em um arquivo de múltiplas partes está faltando, mas pode resultar em falsos positivos.",
    "language-tooltip": "Idioma a ser utilizado pelo Syncplay.",
    "unpause-always-tooltip": "Se você pressionar para despausar, sempre te definirá como pronto e despausará em vez de simplesmente te definir com pronto.",
    "unpause-ifalreadyready-tooltip": "Se você pressionar para despausar quando não estiver pronto, irá te definir como pronto - despause novamente para despausar.",
    "unpause-ifothersready-tooltip": "Se você apertar para despausar quando não estiver pronto, só irá despausar quando outros estiverem prontos.",
    "unpause-ifminusersready-tooltip": "Se você apertar para despausar quando não estiver pronto, só irá despausar quando outros estiverem prontos e o número mínimo de usuários for atingido.",
    "trusteddomains-arguments-tooltip": "Domínios para os quais é permitido trocar automaticamente quando as playlists compartilhadas estiverem habilitadas.",

    "chatinputenabled-tooltip": "Ativar entrada de chat via mpv (pressione Enter para escrever, Enter para enviar, ESC para cancelar)",
    "chatdirectinput-tooltip": "Evita ter de apertar 'Enter' para entrar no modo de entrada de chat no mpv. Pressione TAB no mpv para temporariamente desabilitar esta função.",
    "font-label-tooltip": "Fonte usada ao escrever mensagens no chat no mpv. Apenas no lado do client, portanto não afeta a cor que os outros veem.",
    "set-input-font-tooltip": "Família de fonte usada ao escrever mensagens no chat no mpv. Apenas no lado do client, portanto não afeta a cor que os outros veem.",
    "set-input-colour-tooltip": "Cor de fonte usada ao escrever mensagens no chat no mpv. Apenas no lado do client, portanto não afeta a cor que os outros veem.",
    "chatinputposition-tooltip": "Lugar no mpv onde a entrada de chat será exibida quando você apertar Enter e digitar.",
    "chatinputposition-top-tooltip": "Colocar entrada de chat no topo da janela do mpv.",
    "chatinputposition-middle-tooltip": "Colocar entrada de chat no meio da janela do mpv.",
    "chatinputposition-bottom-tooltip": "Colocar entrada de chat no fundo da janela do mpv.",
    "chatoutputenabled-tooltip": "Mostrar mensagens de chat na tela do reprodutor (OSD) (se suportado pelo reprodutor).",
    "font-output-label-tooltip": "Fonte da saída de chat.",
    "set-output-font-tooltip": "Fonte usada para exibir mensagens do chat.",
    "chatoutputmode-tooltip": "Como as mensagens do chat são exibidas.",
    "chatoutputmode-chatroom-tooltip": "Exibe novas linhas de chat diretamente abaixo da linha anterior.",
    "chatoutputmode-scrolling-tooltip": "Exibe novas linhas de chat rolando-as da direita pra esquerda.",

    "help-tooltip": "Abre o  guia de usuário no Syncplay.pl.",
    "reset-tooltip": "Redefine todas as configurações para seus respectivos padrões.",
    "update-server-list-tooltip": "Conecta ao syncplay.pl para atualizar a lista de servidores públicos.",

    "sslconnection-tooltip": "Conectado com segurança ao servidor. Clique para exibir detalhes do certificado.",

    "joinroom-tooltip": "Sair da sala atual e ingressar na sala especificada.",
    "seektime-msgbox-label": "Saltar para tempo especificado (em segundos ou minutos:segundos). Use + ou - para fazer um pulo relativo ao tempo atual.",
    "ready-tooltip": "Indica se você está pronto para assistir.",
    "autoplay-tooltip": "Reproduzir automaticamente quando todos os usuários que tiverem indicadores de prontidão estiverem prontos e o limiar de usuários for atingido.",
    "switch-to-file-tooltip": "Clique duas vezes para mudar para {}",  # Filename
    "sendmessage-tooltip": "Mandar mensagem para a sala",

    # In-userlist notes (GUI)
    "differentsize-note": "Tamanhos diferentes!",
    "differentsizeandduration-note": "Tamanhos e durações diferentes!",
    "differentduration-note": "Durações diferentes!",
    "nofile-note": "(Nenhum arquivo está sendo tocado)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Você está usando o Syncplay {}, mas uma versão mais nova está disponível em https://syncplay.pl",  # ClientVersion
    "persistent-rooms-notice": "AVISO: Este servidor usa salas persistentes, o que significa que as informações da playlist são salvas entre sessões de reprodução. Se você quer criar uma sala onde a informação não será salva, coloque -temp no final do nome da sala.", # NOTE: Do not translate the word -temp
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "Seja bem-vindo ao servidor de Syncplay, versão {0}",  # version
    "client-connected-room-server-notification": "{0}({2}) conectou-se à sala '{1}'",  # username, host, room
    "client-left-server-notification": "{0} saiu do servidor",  # name
    "no-salt-notification": "POR FAVOR, NOTE: Para permitir que as senhas de operadores de sala geradas por esta instância do servidor ainda funcionem quando o servidor for reiniciado, por favor, adicione o seguinte argumento de linha de comando ao executar o servidor de Syncplay no futuro: --salt {}",  # Salt


    # Server arguments
    "server-argument-description": 'Solução para sincronizar a reprodução de múltiplas instâncias de players de mídia pela rede. Instância de servidor',
    "server-argument-epilog": 'Se nenhuma opção for fornecida, os valores de _config serão utilizados',
    "server-port-argument": 'porta TCP do servidor',
    "server-password-argument": 'senha do servidor',
    "server-isolate-room-argument": 'salas devem ser isoladas?',
    "server-salt-argument": "string aleatória utilizada para gerar senhas de salas gerenciadas",
    "server-disable-ready-argument": "desativar recurso de prontidão",
    "server-motd-argument": "caminho para o arquivo o qual o motd será obtido",
    "server-rooms-argument": "caminho para o arquivo de banco de dádos a ser usado e/ou criado para salvar dados de salas persistentes. Permite que salas persistam sem espectadores e através de reinicializações.",
    "server-permanent-rooms-argument": "caminho para o arquivo que lista salas permanentes que serão listadas mesmo que a sala esteja vazia (na forma de um arquivo de texto que lista uma sala por linha) - requer salas persistentes ativada",
    "server-chat-argument": "O chat deve ser desativado?",
    "server-chat-maxchars-argument": "Número máximo de caracteres numa mensagem do chat (o padrão é {})", # Default number of characters
    "server-maxusernamelength-argument": "Número máximos de caracteres num nome de usuário (o padrão é {})",
    "server-stats-db-file-argument": "Habilita estatísticas de servidor usando o arquivo db SQLite fornecido",
    "server-startTLS-argument": "Habilita conexões TLS usando os arquivos de certificado no caminho fornecido",
    "server-messed-up-motd-unescaped-placeholders": "A Mensagem do Dia possui placeholders não escapados. Todos os sinais de $ devem ser dobrados (como em $$).",
    "server-messed-up-motd-too-long": "A Mensagem do Dia é muito longa - máximo de {} caracteres, {} foram dados.",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "Comando desconhecido: {}",  # message
    "not-json-server-error": "Não é uma string codificada como json: {}",  # message
    "line-decode-server-error": "Não é uma string UTF-8",
    "not-known-server-error": "Você deve ser conhecido pelo servidor antes de mandar este comando",
    "client-drop-server-error": "Cliente desconectado: {} -- {}",  # host, error
    "password-required-server-error": "Senha necessária",
    "wrong-password-server-error": "Senha incorreta fornecida",
    "hello-server-error": "Not enough Hello arguments",  # DO NOT TRANSLATE

    # Playlists
    "playlist-selection-changed-notification":  "{} mudou a seleção da playlist",  # Username
    "playlist-contents-changed-notification": "{} atualizou playlist",  # Username
    "cannot-find-file-for-playlist-switch-error": "Não foi possível encontrar o arquivo {} no diretórios de mídia para a troca de playlist!",  # Filename
    "cannot-add-duplicate-error": "Não foi possível adicionar uma segunda entrada para '{}' para a playlist uma vez que duplicatas não são permitidas.",  # Filename
    "cannot-add-unsafe-path-error": "Não foi possível automaticamente carregar {} porque este não é um domínio confiado. Você pode trocar para a URL manualmente dando um clique duplo nela na playlist e adicionando o domínio aos domínios confiáveis em 'Arquivo -> Avançado -> Definir domínios confiáveis'. Se você clicar com o botão direito na URL, você pode adicionar esta URL como domínio confiável pelo menu de contexto.",  # Filename
    "sharedplaylistenabled-label": "Habilitar playlists compartilhadas",
    "removefromplaylist-menu-label": "Remover da playlist",
    "shuffleremainingplaylist-menu-label": "Embaralhar resto da playlist",
    "shuffleentireplaylist-menu-label": "Embaralhar toda a playlist",
    "undoplaylist-menu-label": "Desfazer última alteração à playlist",
    "addfilestoplaylist-menu-label": "Adicionar arquivo(s) ao final da playlist",
    "addurlstoplaylist-menu-label": "Adicionar URL(s) ao final da playlist",
    "editplaylist-menu-label": "Editar playlist",

    "open-containing-folder": "Abrir pasta contendo este arquivo",
    "addyourfiletoplaylist-menu-label": "Adicionar seu arquivo à playlist",
    "addotherusersfiletoplaylist-menu-label": "Adicionar arquivos de {} à playlist",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Adicionar sua transmissão à playlist",
    "addotherusersstreamstoplaylist-menu-label": "Adicionar transmissão de {} à playlist",  # [Username]
    "openusersstream-menu-label": "Abrir transmissão de {}",  # [username]'s
    "openusersfile-menu-label": "Abrir arquivo de {}",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Arraste um arquivo aqui para adicioná-lo à playlist compartilhada.",
    "sharedplaylistenabled-tooltip": "Operadores da sala podem adicionar arquivos para a playlist compartilhada para tornar mais fácil para todo mundo assistir a mesma coisa. Configure os diretórios de mídia em 'Miscelânea'.",

    "playlist-empty-error": "A playlist está atualemnte vazia.",
    "playlist-invalid-index-error": "Índice inválido na playlist.",
}



import os.path
import subprocess
import time

from syncplay.vendor.python_mpv_jsonipc.python_mpv_jsonipc import log, MPV, MPVError, MPVProcess
from syncplay.utils import resourcespath

class IINA(MPV):
    """The main IINA interface class. Use this to control the MPV player instantiated by IINA."""

    def _start_mpv(self, ipc_socket, mpv_location, **kwargs):
        # Attempt to start IINA 3 times.
        for i in range(3):
            try:
                self.mpv_process = IINAProcess(ipc_socket, mpv_location, **kwargs)
                break
            except MPVError:
                log.warning("IINA start failed.", exc_info=1)
                continue
        else:
            raise MPVError("IINA process retry limit reached.")

class IINAProcess(MPVProcess):
    """
    Manages an IINA process, ensuring the socket or pipe is available. (Internal)
    """

    def _start_process(self, ipc_socket, args, env):
        self.process = subprocess.Popen(args, env=env)
        ipc_exists = False
        for _ in range(100): # Give IINA 10 seconds to start.
            time.sleep(0.1)
            self.process.poll()
            if os.path.exists(ipc_socket):
                ipc_exists = True
                log.debug("Found IINA socket.")
                break
            if self.process.returncode != 0: # iina-cli returns immediately after its start
                log.error("IINA failed with returncode {0}.".format(self.process.returncode))
                break
        else:
            self.process.terminate()
            raise MPVError("IINA start timed out.")
        
        if not ipc_exists or self.process.returncode != 0:
            self.process.terminate()
            raise MPVError("IINA not started.")

    def _get_arglist(self, exec_location, **kwargs):
        args = [exec_location]
        args.append('--no-stdin')
        args.append(resourcespath + 'iina-bkg.png')
        self._set_default(kwargs, "mpv-input-ipc-server", self.ipc_socket)
        args.extend("--{0}={1}".format(v[0].replace("_", "-"), self._mpv_fmt(v[1]))
                    for v in kwargs.items())
        return args



# coding:utf8

"""Deutsch dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

de = {
    "LANGUAGE": "Deutsch",  # (German)
    "LANGUAGE-TAG": "de",

    # Strings for Windows NSIS installer
    "installer-language-file": "German.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "Syncplay als Standardprogramm für Multimedia-Dateien verwenden.",
    "installer-shortcut": "Erstelle Verknüpfungen an folgenden Orten:",
    "installer-start-menu": "Startmenü",
    "installer-desktop": "Desktop",
    "installer-quick-launch-bar": "Schnellstartleiste",
    "installer-automatic-updates": "Automatisch nach Updates suchen;",
    "installer-uninstall-configuration": "Konfigurationsdatei löschen.",

    # Client notifications
    "config-cleared-notification": "Einstellungen gelöscht. Änderungen werden gespeichert, wenn du eine gültige Konfiguration speicherst.",

    "relative-config-notification": "Relative Konfigurationsdatei(en) geladen: {}",

    "connection-attempt-notification": "Verbinde mit {}:{}",  # Port, IP
    "reconnection-attempt-notification": "Verbindung zum Server verloren, versuche erneut",
    "disconnection-notification": "Verbindung zum Server beendet",
    "connection-failed-notification": "Verbindung zum Server fehlgeschlagen",
    "connected-successful-notification": "Erfolgreich mit Server verbunden",
    "retrying-notification": "%s, versuche erneut in %d Sekunden...",  # Seconds
    "reachout-successful-notification": "{} ({}) erfolgreich erreicht",

    "rewind-notification": "Zurückgespult wegen Zeitdifferenz mit {}",  # User
    "fastforward-notification": "Vorgespult wegen Zeitdifferenz mit {}",  # User
    "slowdown-notification": "Verlangsamt wegen Zeitdifferenz mit {}",  # User
    "revert-notification": "Normalgeschwindigkeit",

    "pause-notification": "{} pausierte bei {}",  # User, Time
    "unpause-notification": "{} startete",  # User
    "seek-notification": "{} sprang von {} nach {}",  # User, from time, to time

    "current-offset-notification": "Aktueller Offset: {} Sekunden",  # Offset

    "media-directory-list-updated-notification": "Syncplay-Medienverzeichnisse wurden aktualisiert.",

    "room-join-notification": "{} hat den Raum „{}“ betreten",  # User
    "left-notification": "{} ist gegangen",  # User
    "left-paused-notification": "{} ist gegangen, {} pausierte",  # User who left, User who paused
    "playing-notification": "{} spielt „{}“ ({})",  # User, file, duration
    "playing-notification/room-addendum":  " in Raum: „{}“",  # Room

    "not-all-ready": "Noch nicht bereit: {}",  # Usernames
    "all-users-ready": "Alle sind bereit ({} Nutzer)",  # Number of ready users
    "ready-to-unpause-notification": "Du bist bereit - noch einmal fortsetzen klicken zum abspielen",
    "set-as-ready-notification": "Du bist bereit",
    "set-as-not-ready-notification": "Du bist nicht bereit",
    "autoplaying-notification": "Starte in {}...",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "Identifiziere als Raumleiter mit Passwort „{}“...",  # TODO: find a better translation to "room operator"
    "failed-to-identify-as-controller-notification": "{} konnte sich nicht als Raumleiter identifizieren.",
    "authenticated-as-controller-notification": "{} authentifizierte sich als Raumleiter",
    "created-controlled-room-notification": "Gesteuerten Raum „{}“ mit Passwort „{}“ erstellt. Bitte diese Informationen für die Zukunft aufheben! \n\nIn managed rooms everyone is kept in sync with the room operator(s) who are the only ones who can pause, unpause, seek, and change the playlist.\n\nYou should ask regular viewers to join the room '{}' but the room operators can join the room '{}' to automatically authenticate themselves.", # RoomName, operatorPassword, roomName, roomName:operatorPassword # TODO: Translate

    "other-set-as-ready-notification": "{} was set as ready by {}",  # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "Deine Datei scheint sich von {}s zu unterscheiden",  # User
    "file-differences-notification": "Deine Datei unterscheidet sich auf folgende Art: {}",
    "room-file-differences": "Unterschiedlich in: {}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "Name",
    "file-difference-filesize": "Größe",
    "file-difference-duration": "Dauer",
    "alone-in-the-room": "Du bist alleine im Raum",

    "different-filesize-notification": " (ihre Dateigröße ist anders als deine!)",
    "userlist-playing-notification": "{} spielt:",  # Username
    "file-played-by-notification": "Datei: {} wird gespielt von:",  # File
    "no-file-played-notification": "{} spielt keine Datei ab",  # Username
    "notplaying-notification": "Personen im Raum, die keine Dateien spielen:",
    "userlist-room-notification":  "In Raum „{}“:",  # Room
    "userlist-file-notification": "Datei",
    "controller-userlist-userflag": "Raumleiter",
    "ready-userlist-userflag": "Bereit",

    "update-check-failed-notification": "Konnte nicht automatisch prüfen, ob Syncplay {} aktuell ist. Soll https://syncplay.pl/ geöffnet werden, um manuell nach Updates zu suchen?",  # Syncplay version
    "syncplay-uptodate-notification": "Syncplay ist aktuell",
    "syncplay-updateavailable-notification": "Eine neuere Version von Syncplay ist verfügbar. Soll die Download-Seite geöffnet werden?",

    "mplayer-file-required-notification": "Syncplay für mplayer benötigt eine Dateiangabe beim Start",
    "mplayer-file-required-notification/example": "Anwendungsbeispiel: syncplay [optionen] [url|pfad/]Dateiname",
    "mplayer2-required": "Syncplay ist inkompatibel zu MPlayer 1.x, bitte nutze MPlayer2 oder mpv",

    "unrecognized-command-notification": "Unbekannter Befehl",
    "commandlist-notification": "Verfügbare Befehle:",
    "commandlist-notification/room": "\tr [Name] - Raum ändern",
    "commandlist-notification/list": "\tl - Nutzerliste anzeigen",
    "commandlist-notification/undo": "\tu - Letzter Zeitsprung rückgängig",
    "commandlist-notification/pause": "\tp - Pausieren / weiter",
    "commandlist-notification/seek": "\t[s][+-]Zeit - zu einer bestimmten Zeit spulen, ohne + oder - wird als absolute Zeit gewertet; Angabe in Sekunden oder Minuten:Sekunden",
    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature",
    "commandlist-notification/help": "\th - Diese Hilfe",
    "commandlist-notification/toggle": "\tt - Bereitschaftsanzeige umschalten",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready", # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready", # TODO: Translate
    "commandlist-notification/create": "\tc [name] - erstelle zentral gesteuerten Raum mit dem aktuellen Raumnamen",
    "commandlist-notification/auth": "\ta [password] - authentifiziere als Raumleiter mit Passwort",
    "commandlist-notification/chat": "\tch [message] - Chatnachricht an einem Raum senden",
    "commandList-notification/queue": "\tqa [file/url] - füge Datei oder URL ans Ende der Wiedergabeliste",
    "commandList-notification/queueandselect": "\tqas [file/url] - füge Datei oder URL ans Ende der Wiedergabeliste und wähle diese aus",
    "commandList-notification/playlist": "\tql - zeige aktuelle Wiedergabeliste",
    "commandList-notification/select": "\tqs [index] - wähle den ausgewählten Eintrag in der Wiedergabeliste",
    "commandList-notification/next": "\tqn - wähle den nächsten Eintrag in der Wiedergabeliste",
    "commandList-notification/delete": "\tqd [index] - lösche den ausgewählten Eintrag in der Wiedergabeliste",
    "syncplay-version-notification": "Syncplay Version: {}",  # syncplay.version
    "more-info-notification": "Weitere Informationen auf: {}",  # projectURL

    "gui-data-cleared-notification": "Syncplay hat die Pfad und Fensterdaten der Syncplay-GUI zurückgesetzt.",
    "language-changed-msgbox-label": "Die Sprache wird geändert, wenn du Syncplay neu startest.",
    "promptforupdate-label": "Soll Syncplay regelmäßig nach Updates suchen?",

    "media-player-latency-warning": "Warnung: Der Mediaplayer brauchte {} Sekunden zum Antworten. Wenn Probleme bei der Synchronisation auftreten, schließe bitte andere Anwendungen, um Ressourcen freizugeben. Sollte das nicht funktionieren, versuche es mit einem anderen Media-Player.",  # Seconds to respond
    "mpv-unresponsive-error": "MPV hat für {} Sekunden nicht geantwortet und scheint abgestürzt zu sein. Bitte starte Syncplay neu.",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Enter drücken zum Beenden\n",

    # Client errors
    "missing-arguments-error": "Notwendige Argumente fehlen, siehe --help",
    "server-timeout-error": "Timeout: Verbindung zum Server fehlgeschlagen",
    "mpc-slave-error": "Kann MPC nicht im Slave-Modus starten!",
    "mpc-version-insufficient-error": "MPC-Version nicht ausreichend, bitte nutze `mpc-hc` >= `{}`",
    "mpc-be-version-insufficient-error": "MPC-Version nicht ausreichend, bitte nutze `mpc-be` >= `{}`",
    "mpv-version-error": "Syncplay ist nicht kompatibel mit dieser Version von mpv.  Bitte benutze eine andere Version (z.B. Git HEAD).",
    "mpv-failed-advice": "Der Grund dass mpv nicht gestartet werden kann, kann an der Verwendung nicht unterstützter Befehlszeilenargumente oder einer nicht unterstützten Version von mpv liegen.",
    "player-file-open-error": "Fehler beim Öffnen der Datei durch den Player",
    "player-path-error": "Ungültiger Player-Pfad. Unterstützte Player sind: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 und IINA",
    "hostname-empty-error": "Hostname darf nicht leer sein",
    "empty-error": "{} darf nicht leer sein",  # Configuration
    "media-player-error": "Player-Fehler: \"{}\"",  # Error line
    "unable-import-gui-error": "Konnte die GUI-Bibliotheken nicht importieren. PySide muss installiert sein, damit die grafische Oberfläche funktioniert. If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
    "unable-import-twisted-error": "Twisted konnte nicht importiert werden. Bitte installiere Twisted v16.4.0 oder höher",

    "arguments-missing-error": "Notwendige Argumente fehlen, siehe --help",

    "unable-to-start-client-error": "Client kann nicht gestartet werden",

    "player-path-config-error": "Player-Pfad ist nicht ordnungsgemäß gesetzt. Unterstützte Player sind: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 und IINA",
    "no-file-path-config-error": "Es muss eine Datei ausgewählt werden, bevor der Player gestartet wird.",
    "no-hostname-config-error": "Hostname darf nicht leer sein",
    "invalid-port-config-error": "Port muss gültig sein",
    "empty-value-config-error": "{} darf nicht leer sein",  # Config option

    "not-json-error": "Kein JSON-String\n",
    "hello-arguments-error": "Zu wenige Hello-Argumente\n",
    "version-mismatch-error": "Verschiedene Versionen auf Client und Server\n",
    "vlc-failed-connection": "Kann nicht zu VLC verbinden. Wenn du syncplay.lua nicht installiert hast, findest du auf https://syncplay.pl/LUA/ [Englisch] eine Anleitung. Syncplay and VLC 4 are not currently compatible, so either use VLC 3 or an alternative such as mpv.", # TO DO: TRANSLATE
    "vlc-failed-noscript": "Laut VLC ist das syncplay.lua Interface-Skript nicht installiert. Auf https://syncplay.pl/LUA/ [Englisch] findest du eine Anleitung.",
    "vlc-failed-versioncheck": "Diese VLC-Version wird von Syncplay nicht unterstützt. Bitte nutze VLC 2.0",
    "vlc-initial-warning": 'VLC does not always provide accurate position information to Syncplay, especially for .mp4 and .avi files. If you experience problems with erroneous seeking then please try an alternative media player such as <a href="https://mpv.io/">mpv</a> (or <a href="https://github.com/stax76/mpv.net/">mpv.net</a> for Windows users).', # TODO: Translate

    "feature-sharedPlaylists": "Geteilte Playlists",  # used for not-supported-by-server-error
    "feature-chat": "Chat",  # used for not-supported-by-server-error
    "feature-readiness": "Bereitschaftsstatus",  # used for not-supported-by-server-error
    "feature-managedRooms": "Zentral gesteuerte Räume",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "Diese Funktion wird vom Server nicht unterstützt. Es wird ein Server mit Syncplay Version {}+ benötigt, aktuell verwendet wird jedoch Version {}.",  # minVersion, serverVersion
    "shared-playlists-not-supported-by-server-error": "Die Geteilte-Playlists-Funktion wird von diesem Server eventuell nicht unterstützt. Um ein korrektes Funktionieren sicherzustellen wird ein Server mit Syncplay Version {}+ benötigt, aktuell verwendet wird jedoch Version {}.",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "Die Geteilte-Playlists-Funktion wurde in der Serverkonfiguration deaktiviert. Um diese Funktion zu verwenden, musst du dich mit einem anderen Server verbinden.",

    "invalid-seek-value": "Ungültige Zeitangabe",
    "invalid-offset-value": "Ungültiger Offset-Wert",

    "switch-file-not-found-error": "Konnte nicht zur Datei „{0}“ wechseln. Syncplay sucht im Verzeichnis der aktuellen Datei und angegebenen Medienverzeichnissen.",  # File not found, folder it was not found in
    "folder-search-timeout-error": "Die Suche nach Medien in den Medienverzeichnissen wurde abgebrochen, weil es zu lange gedauert hat, „{}“ zu durchsuchen (after having processed the first {:,} files). Das kann passieren, wenn du in deiner Liste der Medienverzeichnisse ein Verzeichnis mit zu vielen Unterverzeichnissen auswhälst. Damit der automatische Dateiwechsel wieder funktioniert, wähle Datei->Medienverzeichnisse auswählen in der Menüleiste und entferne dieses Verzeichnis oder ersetze es mit einem geeigneten Unterverzeichnis. Wenn das Verzeichnis in Ordnung ist, kannst du es reaktivieren, indem du Datei->Medienverzeichnisse auswählen wählst und „OK“ drückst.", # Folder, Files processed - Note: {:,} is {} but with added commas seprators - TODO: Translate
    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "Die Suche nach Medien in den Medienverzeichnissen wurde abgebrochen, weil es zu lange gedauert hat, auf „{}“ zuzugreifen. Das kann passieren, wenn es sich dabei um ein Netzwerkgerät handelt und du eingestellt hast, dass es sich nach Inaktivität ausschaltet. Damit der automatische Dateiwechsel wieder funktioniert, wähle Datei->Medienverzeichnisse auswählen in der Menüleiste und entferne dieses Verzeichnis oder löse das Problem (z.B. indem du die Energiespareinstellungen anpasst).",  # Folder
    "added-file-not-in-media-directory-error": "Du hast eine Datei in im Verzeichnis „{}“ geladeden, welches kein bekanntes Medienverzeichnis ist. Du kannst es als Medienverzeichnis hinzufügen, indem du  Datei->Medienverzeichnisse auswählen in der Menüleiste wählst.",  # Folder
    "no-media-directories-error": "Es wurden keine Medienverzeichnisse ausgewählt. Damit geteilte Playlists und Dateiwechsel korrekt funktionieren, wähle Datei->Medienverzeichnisse auswählen in der Menüleiste und gib an, wo Syncplay nach Mediendateien suchen soll.",
    "cannot-find-directory-error": "Das Medienverzeichnis „{}“ konnte nicht gefunden werden. Um deine Liste an Medienverzeichnissen anzupassen, wähle Datei->Medienverzeichnisse auswählen in der Menüleiste und gib an, wo Syncplay nach Mediendateien suchen soll.",

    "failed-to-load-server-list-error": "Konnte die Liste der öffentlichen Server nicht laden. Bitte besuche https://www.syncplay.pl/ [Englisch] mit deinem Browser.",

    # Client arguments
    "argument-description": 'Syncplay ist eine Anwendung um mehrere MPlayer, MPC-HC, MPC-BE und VLC-Instanzen über das Internet zu synchronisieren.',
    "argument-epilog": 'Wenn keine Optionen angegeben sind, werden die _config-Werte verwendet',
    "nogui-argument": 'Keine GUI anzeigen',
    "host-argument": 'Server-Adresse',
    "name-argument": 'Gewünschter Nutzername',
    "debug-argument": 'Debug-Modus',
    "force-gui-prompt-argument": 'Einstellungsfenster anzeigen',
    "no-store-argument": 'keine Werte in .syncplay speichern',
    "room-argument": 'Standard-Raum',
    "password-argument": 'Server-Passwort',
    "player-path-argument": 'Pfad zum Player',
    "file-argument": 'Abzuspielende Datei',
    "args-argument": 'Player-Einstellungen; Wenn du Einstellungen, die mit - beginnen, nutzen willst, stelle ein einzelnes \'--\'-Argument davor',
    "clear-gui-data-argument": 'Setzt die Pfad- und GUI-Fenster-Daten die in den QSettings gespeichert sind zurück',
    "language-argument": 'Sprache für Syncplay-Nachrichten ({})', # Languages

    "version-argument": 'gibt die aktuelle Version aus',
    "version-message": "Du verwendest Syncplay v. {} ({})",

    "load-playlist-from-file-argument": "lädt eine Playlist aus einer Textdatei (ein Eintrag pro Zeile)",

    # Client labels
    "config-window-title": "Syncplay-Konfiguration",

    "connection-group-title": "Verbindungseinstellungen",
    "host-label": "Server-Adresse:",
    "name-label":  "Benutzername (optional):",
    "password-label":  "Server-Passwort (falls nötig):",
    "room-label": "Standard-Raum:",
    "roomlist-msgbox-label": "Bearbeite Raum Liste (eins pro Linie)",

    "media-setting-title": "Media-Player Einstellungen",
    "executable-path-label": "Pfad zum Media-Player:",
    "media-path-label": "Pfad zum Video (optional):",
    "player-arguments-label": "Playerparameter:",
    "browse-label": "Durchsuchen",
    "update-server-list-label": "Liste aktualisieren",

    "more-title": "Mehr Einstellungen zeigen",
    "never-rewind-value": "Niemals",
    "seconds-suffix": " sek",
    "privacy-sendraw-option": "Klartext senden",
    "privacy-sendhashed-option": "Hash senden",
    "privacy-dontsend-option": "Nicht senden",
    "filename-privacy-label": "Dateiname:",
    "filesize-privacy-label": "Dateigröße:",
    "checkforupdatesautomatically-label": "Automatisch nach Updates suchen",
    "slowondesync-label": "Verlangsamen wenn nicht synchron (nicht unterstützt mit MPC-HC/BE)",
    "dontslowdownwithme-label": "Nie verlangsamen oder andere zurückspulen (Experimentell)",
    "pausing-title": "Pausiere",
    "pauseonleave-label": "Pausieren wenn ein Benutzer austritt",
    "readiness-title": "Anfänglicher Bereitschaftsstatus",
    "readyatstart-label": "Standardmäßig auf „Bereit“ stellen",
    "forceguiprompt-label": "Diesen Dialog nicht mehr anzeigen",
    "showosd-label": "OSD-Nachrichten anzeigen",

    "showosdwarnings-label": "Zeige Warnungen (z.B. wenn Dateien verschieden)",
    "showsameroomosd-label": "Zeige Ereignisse in deinem Raum",
    "shownoncontrollerosd-label": "Zeige Ereignisse von nicht geführten Räumen in geführten Räumen.",
    "showdifferentroomosd-label": "Zeige Ereignisse in anderen Räumen",
    "showslowdownosd-label": "Zeige Verlangsamungs/Zurücksetzungs-Benachrichtigung",
    "language-label": "Sprache:",
    "automatic-language": "Automatisch ({})",  # Default language
    "showdurationnotification-label": "Zeige Warnung wegen unterschiedlicher Dauer",
    "basics-label": "Grundlagen",
    "readiness-label": "Play/Pause",
    "misc-label": "Diverse",
    "core-behaviour-title": "Verhalten des Raumes",
    "syncplay-internals-title": "Syncplay intern",
    "syncplay-mediasearchdirectories-title": "In diesen Verzeichnissen nach Medien suchen",  # needs to be checked
    "syncplay-mediasearchdirectories-label": "In diesen Verzeichnissen nach Medien suchen (ein Pfad pro Zeile)",
    "sync-label": "Synchronisation",
    "sync-otherslagging-title": "Wenn andere laggen...",
    "sync-youlaggging-title": "Wenn du laggst...",
    "messages-label": "Nachrichten",
    "messages-osd-title": "OSD-(OnScreenDisplay)-Einstellungen",
    "messages-other-title": "Weitere Display-Einstellungen",
    "chat-label": "Chat",
    "privacy-label": "Privatsphäre",
    "privacy-title": "Privatsphäreneinstellungen",
    "unpause-title": "Wenn du Play drückst, auf Bereit setzen und:",
    "unpause-ifalreadyready-option": "Wiedergeben wenn bereits als Bereit gesetzt",
    "unpause-ifothersready-option": "Wiedergeben wenn bereits als Bereit gesetzt oder alle anderen bereit sind (Standard)",
    "unpause-ifminusersready-option": "Wiedergeben wenn bereits als Bereit gesetzt oder die minimale Anzahl anderer Nutzer bereit ist",
    "unpause-always": "Immer wiedergeben",
    "syncplay-trusteddomains-title": "Vertrauenswürdige Domains (für Streamingdienste und gehostete Inhalte)",

    "chat-title": "Chatnachrichten-Eingabe",
    "chatinputenabled-label": "Chateingabe via mpv erlauben (mit der Entertaste)",
    "chatdirectinput-label": "Sofotige Chateingabe erlauben (ohne die Entertaste zu drücken)",
    "chatinputfont-label": "Chateingabe-Schriftart",
    "chatfont-label": "Schriftart wählen",
    "chatcolour-label": "Farbe wählen",
    "chatinputposition-label": "Position des Nachrichteneingabe-Felds in mpv",
    "chat-top-option": "Oben",
    "chat-middle-option": "Mitte",
    "chat-bottom-option": "Unten",
    "chatoutputheader-label": "Chatnachrichten-Eingabe",
    "chatoutputfont-label": "Chateingabe-Schriftart",
    "chatoutputenabled-label": "Chatausgabe im Medienplayer aktivieren (bisher nur mpv)",
    "chatoutputposition-label": "Ausgabemodus",
    "chat-chatroom-option": "Chatroom-Stil",
    "chat-scrolling-option": "Scrolling-Stil",

    "mpv-key-tab-hint": "[TAB] um Zugriff auf die Buchstabentastenkürzel ein-/auszuschalten.",
    "mpv-key-hint": "[ENTER] um eine Nachricht zu senden. [ESC] um den Chatmodus zu verlassen.",
    "alphakey-mode-warning-first-line": "Du kannst vorübergehend die alten mpv-Tastaturkürzel mit den a–z-Tasten verwenden.",
    "alphakey-mode-warning-second-line": "Drücke [TAB], um in den Syncplay-Chatmodus zurückzukehren.",

    "help-label": "Hilfe",
    "reset-label": "Auf Standardwerte zurücksetzen",
    "run-label": "Syncplay starten",
    "storeandrun-label": "Konfiguration speichern und Syncplay starten",

    "contact-label": "Du hast eine Idee, einen Bug gefunden oder möchtest Feedback geben? Sende eine E-Mail an <a href=\"mailto:dev@syncplay.pl\">dev@syncplay.pl</a> oder <a href=\"https://github.com/Syncplay/syncplay/issues\">öffne eine Fehlermeldung auf GitHub</a> / <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>start a discussion</nobr></a> to make a suggestion or ask a question via GitHub,. Außerdem findest du auf <a href=\"https://syncplay.pl/\">https://syncplay.pl/</a> weitere Informationen, Hilfestellungen und Updates. Chatnachrichten sind nicht verschlüsselt, also verwende Syncplay nicht, um sensible Daten zu verschicken.", # TODO: Update translation

    "joinroom-label": "Raum beitreten",
    "joinroom-menu-label": "Raum beitreten {}",  # TODO: Might want to fix this
    "seektime-menu-label": "Spule zu Zeit",
    "undoseek-menu-label": "Rückgängig",
    "play-menu-label": "Wiedergabe",
    "pause-menu-label": "Pause",
    "playbackbuttons-menu-label": "Wiedergabesteuerung anzeigen",
    "autoplay-menu-label": "Auto-Play-Knopf anzeigen",
    "autoplay-guipushbuttonlabel": "Automatisch abspielen wenn alle bereit sind",
    "autoplay-minimum-label": "Minimum an Nutzern:",
    "hideemptyrooms-menu-label": "Hide empty persistent rooms", # TODO: Translate

    "sendmessage-label": "Senden",

    "ready-guipushbuttonlabel": "Ich bin bereit zum Gucken!",

    "roomuser-heading-label": "Raum / Benutzer",
    "size-heading-label": "Größe",
    "duration-heading-label": "Länge",
    "filename-heading-label": "Dateiname",
    "notifications-heading-label": "Benachrichtigungen",
    "userlist-heading-label": "Liste der gespielten Dateien",

    "browseformedia-label": "Nach Mediendateien durchsuchen",

    "file-menu-label": "&Datei",  # & precedes shortcut key
    "openmedia-menu-label": "&Mediendatei öffnen...",
    "openstreamurl-menu-label": "&Stream URL öffnen",
    "setmediadirectories-menu-label": "Medienverzeichnisse &auswählen",
    "loadplaylistfromfile-menu-label": "&Lade Playlist aus Datei",
    "saveplaylisttofile-menu-label": "&Speichere Playlist in Datei",
    "exit-menu-label": "&Beenden",
    "advanced-menu-label": "&Erweitert",
    "window-menu-label": "&Fenster",
    "setoffset-menu-label": "&Offset einstellen",
    "createcontrolledroom-menu-label": "&Zentral gesteuerten Raum erstellen",
    "identifyascontroller-menu-label": "Als Raumleiter &identifizieren",
    "settrusteddomains-menu-label": "&Vertrauenswürdige Domains auswählen",
    "addtrusteddomain-menu-label": "{} als vertrauenswürdige Domain hinzufügen",  # Domain

    "edit-menu-label": "&Bearbeiten",
    "cut-menu-label": "Aus&schneiden",
    "copy-menu-label": "&Kopieren",
    "paste-menu-label": "&Einsetzen",
    "selectall-menu-label": "&Alles auswälhen",

    "playback-menu-label": "&Wiedergabe",

    "help-menu-label": "&Hilfe",
    "userguide-menu-label": "&Benutzerhandbuch öffnen",
    "update-menu-label": "auf &Aktualisierung prüfen",

    # startTLS messages
    "startTLS-initiated": "Sichere Verbindung wird versucht",
    "startTLS-secure-connection-ok": "Sichere Verbindung hergestellt ({})",
    "startTLS-server-certificate-invalid": 'Sichere Verbindung fehlgeschlagen. Der Server benutzt ein ungültiges Sicherheitszertifikat. Der Kanal könnte von Dritten abgehört werden. Für weitere Details und Problemlösung siehe <a href="https://syncplay.pl/trouble">hier</a> [Englisch].',
    "startTLS-server-certificate-invalid-DNS-ID": "Syncplay vertraut diesem Server nicht, da er ein Zertifikat verwendet, das für seinen Hostnamen ungültig ist.",
    "startTLS-not-supported-client": "Dieser Client unterstützt kein TLS",
    "startTLS-not-supported-server": "Dieser Server unterstützt kein TLS",

    # TLS certificate dialog
    "tls-information-title": "Zertifikatdetails",
    "tls-dialog-status-label": "<strong>Syncplay nutzt eine verschlüsselte Verbindung zu {}.</strong>",
    "tls-dialog-desc-label": "Verschlüsselung mit einem digitalen Zertifikat hält Informationen geheim, die vom Server {} gesendet oder empfangen werden.",
    "tls-dialog-connection-label": "Daten werden verschlüsselt mit Transport Layer Security (TLS) Version {} und <br/>folgender Chiffre: {}.",
    "tls-dialog-certificate-label": "Zertifikat ausgestellt durch {} gültig bis {}.",

    # About dialog
    "about-menu-label": "&Über Syncplay",
    "about-dialog-title": "Über Syncplay",
    "about-dialog-release": "Version {} Release {}",
    "about-dialog-license-text": "Lizensiert unter der Apache-Lizenz&nbsp;Version 2.0",
    "about-dialog-license-button": "Lizenz",
    "about-dialog-dependencies": "Abhängigkeiten",

    "setoffset-msgbox-label": "Offset einstellen",
    "offsetinfo-msgbox-label": "Offset (siehe https://syncplay.pl/guide/ für eine Anleitung [Englisch]):",

    "promptforstreamurl-msgbox-label": "Stream-URL öffnen",
    "promptforstreamurlinfo-msgbox-label": "Stream-URL",

    "addfolder-label": "Verzeichnis hinzufügen",

    "adduris-msgbox-label": "URLs zur Playlist hinzufügen (ein Eintrag pro Zeile)",
    "editplaylist-msgbox-label": "Playlist auswählen (ein Eintrag pro Zeile)",
    "trusteddomains-msgbox-label": "Domains, zu denen automatisch gewechselt werden darf (ein Eintrag pro Zeile)",

    "createcontrolledroom-msgbox-label": "Zentral gesteuerten Raum erstellen",
    "controlledroominfo-msgbox-label": "Namen des zentral gesteuerten Raums eingeben\r\n(siehe https://syncplay.pl/guide/ für eine Anleitung [Englisch]):",

    "identifyascontroller-msgbox-label": "Als Raumleiter identifizieren",
    "identifyinfo-msgbox-label": "Passwort des zentral gesteuerten Raums eingeben\r\n(siehe https://syncplay.pl/guide/ für eine Anleitung [Englisch]):",

    "public-server-msgbox-label": "Einen öffentlichen Server für diese Sitzung auswählen",

    "megabyte-suffix": " MB",

    # Tooltips

    "host-tooltip": "Hostname oder IP zu der verbunden werden soll. Optional mit Port (z.B.. syncplay.pl:8999). Synchronisation findet nur mit Personen auf dem selben Server und Port statt.",
    "name-tooltip": "Dein Benutzername. Keine Registrierung, kann einfach geändert werden. Bei fehlender Angabe wird ein zufälliger Name generiert.",
    "password-tooltip": "Passwörter sind nur bei Verbindung zu privaten Servern nötig.",
    "room-tooltip": "Der Raum, der betreten werden soll, kann ein x-beliebiger sein. Allerdings werden nur Clients im selben Raum synchronisiert.",

    "edit-rooms-tooltip": "Bearbeite Raum Liste.",

    "executable-path-tooltip": "Pfad zum ausgewählten, unterstützten Mediaplayer (mpv, mpv.net, VLC, MPC-HC/BE, mplayer2, oder IINA).",
    "media-path-tooltip": "Pfad zum wiederzugebenden Video oder Stream. Notwendig für mplayer2.",
    "player-arguments-tooltip": "Zusätzliche Kommandozeilenparameter/-schalter für diesen Mediaplayer.",
    "mediasearcdirectories-arguments-tooltip": "Verzeichnisse, in denen Syncplay nach Mediendateien suchen soll, z.B. wenn du die Click-to-switch-Funktion verwendest. Syncplay wird Unterverzeichnisse rekursiv durchsuchen.",  # TODO: Translate Click-to-switch? (or use as name for feature)

    "more-tooltip": "Weitere Einstellungen anzeigen.",
    "filename-privacy-tooltip": "Privatheitsmodus beim Senden des Namens der aktuellen Datei zum Server.",
    "filesize-privacy-tooltip": "Privatheitsmodus beim Senden der Größe der aktuellen Datei zum Server.",
    "privacy-sendraw-tooltip": "Die Information im Klartext übertragen. Dies ist die Standard-Einstellung mit der besten Funktionalität.",
    "privacy-sendhashed-tooltip": "Die Informationen gehasht übertragen, um sie für andere Clients schwerer lesbar zu machen.",
    "privacy-dontsend-tooltip": "Diese Information nicht übertragen. Dies garantiert den größtmöglichen Datanschutz.",
    "checkforupdatesautomatically-tooltip": "Regelmäßig auf der Syncplay-Website nach Updates suchen.",
    "autosavejoinstolist-tooltip": "When you join a room in a server, automatically remember the room name in the list of rooms to join.", # TO DO: Translate
    "autosavejoinstolist-label": "Add rooms you join to the room list e", # TO DO: Translate
    "slowondesync-tooltip": "Reduziert die Abspielgeschwindigkeit zeitweise, um die Synchronität zu den anderen Clients wiederherzustellen.",
    "rewindondesync-label": "Zurückspulen bei großer Zeitdifferenz (empfohlen)",
    "fastforwardondesync-label": "Vorspulen wenn das Video laggt (empfohlen)",
    "dontslowdownwithme-tooltip": "Lässt andere nicht langsamer werden oder zurückspringen, wenn deine Wiedergabe hängt.",
    "pauseonleave-tooltip": "Wiedergabe anhalten, wenn deine Verbindung verloren geht oder jemand den Raum verlässt.",
    "readyatstart-tooltip": "Zu Beginn auf „Bereit“ setzen (sonst bist du als „Nicht Bereit“ gesetzt, bis du den Status änderst)",
    "forceguiprompt-tooltip": "Der Konfigurationsdialog wird nicht angezeigt, wenn eine Datei mit Syncplay geöffnet wird.",
    "nostore-tooltip": "Syncplay mit den angegebenen Einstellungen starten, diese aber nicht dauerhaft speichern.",
    "rewindondesync-tooltip": "Zum Wiederherstellen der Synchronität in der Zeit zurückspringen (empfohlen)",
    "fastforwardondesync-tooltip": "Nach vorne springen, wenn asynchron zum Raumleiter (oder deine vorgetäuschte Position, falls „Niemals verlangsamen oder andere zurückspulen“ aktiviert ist).",
    "showosd-tooltip": "Syncplay-Nachrichten auf dem OSD (= OnScreenDisplay, ein eingeblendetes Textfeld) des Players anzeigen.",
    "showosdwarnings-tooltip": "Warnungen bei Unterschiedlichen Dateien oder Alleinsein im Raum anzeigen.",
    "showsameroomosd-tooltip": "OSD-Meldungen über Ereignisse im selben Raum anzeigen.",
    "shownoncontrollerosd-tooltip": "OSD-Meldungen bei Ereignissen verursacht durch nicht-Raumleiter in zentral gesteuerten Räumen anzeigen.",
    "showdifferentroomosd-tooltip": "OSD-Meldungen zu anderen Räumen als dem aktuell betretenen anzeigen.",
    "showslowdownosd-tooltip": "Meldungen bei Geschwindigkeitsänderung anzeigen.",
    "showdurationnotification-tooltip": "Nützlich, wenn z.B. ein Teil eines mehrteiligen Videos fehlt, kann jedoch auch fehlerhaft anschlagen.",
    "language-tooltip": "Die verwendete Sprache von Syncplay",
    "unpause-always-tooltip": "Wiedergabe startet immer (anstatt nur den Bereitschaftsstatus zu ändern)",
    "unpause-ifalreadyready-tooltip": "Wenn du nicht bereit bist und Play drückst wirst du als bereit gesetzt - zum Starten der Wiedergabe nochmal drücken.",
    "unpause-ifothersready-tooltip": "Wenn du Play drückst und nicht bereit bist, wird nur gestartet, wenn alle anderen bereit sind.",
    "unpause-ifminusersready-tooltip": "Wenn du Play drückst und nicht bereit bist, wird nur gestartet, wenn die minimale Anzahl anderer Benutzer bereit ist.",
    "trusteddomains-arguments-tooltip": "Domains, zu denen Syncplay automatisch wechself darf, wenn geteilte Playlists aktiviert sind.",

    "chatinputenabled-tooltip": "Chateingabe in mpv aktivieren (Drücke Enter zum Chatten, Enter zum Senden, Esc um abzubrechen)",
    "chatdirectinput-tooltip": "Überspringe, Enter drücken zu müssen, um in mpv in den Chatmodus zu gelangen. Drücke TAB, um diese Funktion vorübergehend zu deaktivieren.",
    "font-label-tooltip": "Schriftart für die Darstellung der Chateingabe in mpv. Nur clientseitig, beeinflusst also nicht, was andere sehen.",
    "set-input-font-tooltip": "Schriftfamilie für die Darstellung der Chateingabe in mpv. Nur clientseitig, beeinflusst also nicht, was andere sehen.",
    "set-input-colour-tooltip": "Schriftfarbe für die Darstellung der Chateingabe in mpv. Nur clientseitig, beeinflusst also nicht, was andere sehen.",
    "chatinputposition-tooltip": "Position in mpv, an der Text der Chateingabe erscheint, wenn du Enter drückst und tippst.",
    "chatinputposition-top-tooltip": "Chateingabe oben im mpv-Fenster platzieren.",
    "chatinputposition-middle-tooltip": "Chateingabe mittig im mpv-Fenster platzieren.",
    "chatinputposition-bottom-tooltip": "Chateingabe unten im mpv-Fenster platzieren.",
    "chatoutputenabled-tooltip": "Chatnachrichten im OSD anzeigen (sofern vom Medienplayer unterstützt).",
    "font-output-label-tooltip": "Chatausgabe-Schriftart.",
    "set-output-font-tooltip": "Schriftart für die Darstellung von Chatnachrichten.",
    "chatoutputmode-tooltip": "Wie Chatnachrichten dargestellt werden.",
    "chatoutputmode-chatroom-tooltip": "Neue Chatzeilen unmittelbar unterder vorangehenden Zeile anzeigen.",
    "chatoutputmode-scrolling-tooltip": "Chat-Text von rechts nach links scrollen lassen",

    "help-tooltip": "Öffnet Hilfe auf syncplay.pl [Englisch]",
    "reset-tooltip": "Alle Einstellungen auf Standardwerte zurücksetzen.",
    "update-server-list-tooltip": "Mit syncplay.pl verbinden um die Liste öffentlicher Server zu aktualisieren.",

    "sslconnection-tooltip": "Sicher mit Server verbunden. Klicken, um Zertifikatdetails anzuzeigen.",

    "joinroom-tooltip": "Den aktuellen Raum verlassen und stattdessen den angegebenen betreten.",
    "seektime-msgbox-label": "Springe zur angegebenen Zeit (in Sekunden oder min:sek).  Verwende +/- zum relativen Springen.",
    "ready-tooltip": "Zeigt an, ob du bereit zum anschauen bist",
    "autoplay-tooltip": "Automatisch abspielen, wenn alle Nutzer bereit sind oder die minimale Nutzerzahl erreicht ist.",
    "switch-to-file-tooltip": "Doppelklicken um zu {} zu wechseln",  # Filename
    "sendmessage-tooltip": "Nachricht an Raum senden",

    # In-userlist notes (GUI)
    "differentsize-note": "Verschiedene Größe!",
    "differentsizeandduration-note": "Verschiedene Größe und Dauer!",
    "differentduration-note": "Verschiedene Dauer!",
    "nofile-note": "(keine Datei wird abgespielt)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Du nutzt Syncplay Version {}, aber es gibt eine neuere Version auf https://syncplay.pl",  # ClientVersion
    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # TO DO: Translate - NOTE: Do not translate the word -temp
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "Willkommen zum Syncplay-Server, v. {0}",  # version
    "client-connected-room-server-notification": "{0}({2}) hat den Raum „{1}“ betreten",  # username, host, room
    "client-left-server-notification": "{0} hat den Server verlassen",  # name
    "no-salt-notification": "WICHTIGER HINWEIS: Damit von dem Server generierte Passwörter für geführte Räume auch nach einem Serverneustart funktionieren, starte den Server mit dem folgenden Parameter: --salt {}",  # Salt

    # Server arguments
    "server-argument-description": 'Anwendung, um mehrere MPlayer, MPC-HC/BE und VLC-Instanzen über das Internet zu synchronisieren. Server',
    "server-argument-epilog": 'Wenn keine Optionen angegeben sind, werden die _config-Werte verwendet',
    "server-port-argument": 'Server TCP-Port',
    "server-password-argument": 'Server-Passwort',
    "server-isolate-room-argument": 'Sollen die Räume isoliert sein?',
    "server-salt-argument": "zufällige Zeichenkette, die zur Erstellung von Passwörtern verwendet wird",
    "server-disable-ready-argument": "Bereitschaftsfeature deaktivieren",
    "server-motd-argument": "Pfad zur Datei, von der die Nachricht des Tages geladen wird",
    "server-rooms-argument": "path to database file to use and/or create to store persistent room data. Enables rooms to persist without watchers and through restarts", # TODO: Translate
    "server-permanent-rooms-argument": "path to file which lists permenant rooms that will be listed even if the room is empty (in the form of a text file which lists one room per line) - requires persistent rooms to be enabled", # TODO: Translate
    "server-chat-argument": "Soll Chat deaktiviert werden?",
    "server-chat-maxchars-argument": "Maximale Zeichenzahl in einer Chatnachricht (Standard ist {})",
    "server-maxusernamelength-argument": "Maximale Zeichenzahl in einem Benutzernamen (Standard ist {})",
    "server-stats-db-file-argument": "Aktiviere Server-Statistiken mithilfe der bereitgestellten SQLite-db-Datei",
    "server-startTLS-argument": "Erlaube TLS-Verbindungen mit den Zertifikatdateien im Angegebenen Pfad",
    "server-messed-up-motd-unescaped-placeholders": "Die Nachricht des Tages hat unmaskierte Platzhalter. Alle $-Zeichen sollten verdoppelt werden ($$).",
    "server-messed-up-motd-too-long": "Die Nachricht des Tages ist zu lang - Maximal {} Zeichen, aktuell {}.",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "Unbekannter Befehl {}",  # message
    "not-json-server-error": "Kein JSON-String {}",  # message
    "line-decode-server-error": "Keine utf-8-Zeichenkette",
    "not-known-server-error": "Der Server muss dich kennen, bevor du diesen Befehl nutzen kannst",
    "client-drop-server-error": "Client verloren: {} -- {}",  # host, error
    "password-required-server-error": "Passwort nötig",
    "wrong-password-server-error": "Ungültiges Passwort",
    "hello-server-error": "Zu wenige Hello-Argumente",

    # Playlists
    "playlist-selection-changed-notification":  "{} hat die Playlist-Auswahl geändert",  # Username
    "playlist-contents-changed-notification": "{} hat die Playlist aktualisiert",  # Username
    "cannot-find-file-for-playlist-switch-error": "Die Datei {} konnte zum Dateiwechsel nicht in den Medienverzeichnissen gefunden werden!",  # Filename
    "cannot-add-duplicate-error": "Konnte zweiten Eintrag für „{}“ nicht zur Playlist hinzufügen, weil Dubletten nicht erlaubt sind.",  # Filename
    "cannot-add-unsafe-path-error": "{} konnte nicht automatisch geladen werden, weil es sich nicht um eine vertrauenswürdige Domain handelt. Du kannst manuell zu der URL wechseln, indem du sie in der Playlist doppelklickst oder vertrauenswürdige Domains unter Datei->Erweitert->Vertrauenswürdige Domains auswählen hinzufügst. Wenn du einen Rechtsklick auf eine URL ausführst, kannst du ihre Domain im Kontextmenü als vertrauenswürdig hinzufügen.",  # Filename
    "sharedplaylistenabled-label": "Geteilte Playlists aktivieren",
    "removefromplaylist-menu-label": "Von Playlist entfernen",
    "shuffleremainingplaylist-menu-label": "Verbleibende Playlist shuffeln",
    "shuffleentireplaylist-menu-label": "Gesamte Playlist shuffeln",
    "undoplaylist-menu-label": "Letze Playlist-Änderung rückgängig machen",
    "addfilestoplaylist-menu-label": "Datei(en) zum Ende der Playlist hinzufügen",
    "addurlstoplaylist-menu-label": "URL(s) zum Ende der Playlist hinzufügen",
    "editplaylist-menu-label": "Playlist bearbeiten",

    "open-containing-folder": "Übergeordnetes Verzeichnis der Datei öffnen",
    "addyourfiletoplaylist-menu-label": "Deine Datei zur Playlist hinzufügen",
    "addotherusersfiletoplaylist-menu-label": "{}s Datei zur Playlist hinzufügen",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Deinen Stream zur Playlist hinzufügen",
    "addotherusersstreamstoplaylist-menu-label": "{}s Stream zur Playlist hinzufügen",  # [Username]
    "openusersstream-menu-label": "{}s Stream öffnen",  # [username]'s
    "openusersfile-menu-label": "{}s Datei öffnen",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Zieh eine Datei hierher, um sie zur geteilten Playlist hinzuzufügen.",
    "sharedplaylistenabled-tooltip": "Raumleiter können Dateien zu einer geteilten Playlist hinzufügen und es so erleichtern, gemeinsam das Gleiche zu gucken. Konfiguriere Medienverzeichnisse unter „Diverse“",

    "playlist-empty-error": "Wiedergabeliste is aktuell leer.",
    "playlist-invalid-index-error": "Ungültiger Wiedergabelisten-Index",
}
